<?php

/**
 * @file
 * theme-settings.php
 *
 * Provides theme settings for diba_clean.
 */

use Drupal\Core\Form\FormStateInterface;

/**
 * Implements hook_form_FORM_ID_alter().
 */
function diba_clean_form_system_theme_settings_alter(&$form, FormStateInterface $form_state, $form_id = NULL) {
  // Work-around for a core bug affecting admin themes.
  // @see http://drupal.org/node/943212
  if (isset($form_id)) {
    return;
  }

  // Remove unused bootstrap 5 parent theme settings.
  unset($form['styleguide']);
  unset($form['body_details']);
  unset($form['nav_details']);
  unset($form['footer_details']);
  unset($form['text_formats']);
  unset($form['subtheme']);

  // Theme settings.
  $form['home_logo'] = [
    '#type' => 'details',
    '#title' => t('Home logo'),
    '#open' => TRUE,
  ];
  $help = t('Can use absolute or relative paths. For example: /themes/contrib/diba_clean/logo.svg');
  $form['home_logo']['dc_logo1_path'] = [
    '#type' => 'textfield',
    '#title' => t('Main logo path'),
    '#default_value' => theme_get_setting('dc_logo1_path'),
    '#description' => $help,
    '#maxlength' => 1024,
  ];
  $form['home_logo']['dc_logo1_link'] = [
    '#type' => 'textfield',
    '#title' => t('Main logo link'),
    '#default_value' => theme_get_setting('dc_logo1_link'),
    '#maxlength' => 1024,
  ];
  $form['home_logo']['dc_logo1_label'] = [
    '#type' => 'textfield',
    '#title' => t('Main logo label'),
    '#default_value' => theme_get_setting('dc_logo1_label'),
    '#maxlength' => 1024,
  ];
  $form['home_logo']['dc_logo2_path'] = [
    '#type' => 'textfield',
    '#title' => t('Secondary logo path'),
    '#default_value' => theme_get_setting('dc_logo2_path'),
    '#description' => $help,
    '#maxlength' => 1024,
  ];
  $form['home_logo']['dc_logo2_link'] = [
    '#type' => 'textfield',
    '#title' => t('Secondary logo link'),
    '#default_value' => theme_get_setting('dc_logo2_link'),
    '#maxlength' => 1024,
  ];
  $form['home_logo']['dc_logo2_label'] = [
    '#type' => 'textfield',
    '#title' => t('Secondary logo label'),
    '#default_value' => theme_get_setting('dc_logo2_label'),
    '#maxlength' => 1024,
  ];

  $colorList = [
    'diba' => '#9D2235',
    'color1' => '#E72362',
    'color2' => '#89C14A',
    'color3' => '#F34438',
    'color4' => '#FE9603',
    'color5' => '#2594F2',
    'color6' => '#FEBF0F',
    'color7' => '#009486',
    'color8' => '#00BAD2',
    'color9' => '#922A6C',
    'color10' => '#4CAD50',
    'color11' => '#775549',
    'color12' => '#4051B3',
    'color13' => '#003676',
    'color14' => '#a03022',
    'color15' => '#c4629c',
    'color16' => '#E71D73',
    'color17' => '#1361A8',
  ];
  $colorOptions = $colorTags = [];
  foreach ($colorList as $key => $value) {
    $text = $key . ' (' . $value . ')';
    $colorOptions['theme-' . $key] = $text;
    $colorTags[] = '<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="' . $value . '" class="bi bi-circle-fill" viewBox="0 0 16 16"><circle cx="8" cy="8" r="8"/></svg> ' . $text;
  }
  $form['color_schema'] = [
    '#type' => 'details',
    '#title' => t('Color schema'),
    '#open' => TRUE,
  ];
  $form['color_schema']['help'] = [
    '#type' => 'markup',
    '#markup' => implode(' ', $colorTags),
    '#allowed_tags' => ['svg', 'circle'],
  ];
  $form['color_schema']['dc_color_schema'] = [
    '#type' => 'select',
    '#title' => t('Color schema'),
    '#default_value' => theme_get_setting('dc_color_schema'),
    '#options' => $colorOptions,
  ];

  $form['regions'] = [
    '#type' => 'details',
    '#title' => t('Region options'),
    '#open' => TRUE,
  ];
  $containerOptions = [
    'container' => 'container',
    'container-fluid' => 'container-fluid',
  ];
  $form['regions']['dc_secondary_menu_type'] = [
    '#type' => 'select',
    '#title' => t('Secondary menu'),
    '#default_value' => theme_get_setting('dc_secondary_menu_type'),
    '#options' => [
      'full' => 'full width',
      'condensed' => 'condensed left',
    ],
  ];
  $form['regions']['dc_precontent_container'] = [
    '#type' => 'select',
    '#title' => t('Pre-content container'),
    '#default_value' => theme_get_setting('dc_precontent_container'),
    '#options' => $containerOptions,
  ];
  $form['regions']['dc_content_container'] = [
    '#type' => 'select',
    '#title' => t('Content container'),
    '#default_value' => theme_get_setting('dc_content_container'),
    '#options' => $containerOptions,
  ];
  $form['regions']['dc_postcontent_container'] = [
    '#type' => 'select',
    '#title' => t('Post-Content container'),
    '#default_value' => theme_get_setting('dc_postcontent_container'),
    '#options' => $containerOptions,
  ];

  $help = t('Can use classes for changing elements order in different displays or justify text.');
  $form['regions']['dc_content_class'] = [
    '#type' => 'textfield',
    '#title' => t('Content class'),
    '#default_value' => theme_get_setting('dc_content_class') ?? 'order-1 order-lg-2 text-justify',
    '#description' => $help . ' ' . t('Example: %s', ['%s' => 'order-1 order-lg-2 text-justify']),
  ];
  $form['regions']['dc_sidebar_left_class'] = [
    '#type' => 'textfield',
    '#title' => t('Sidebar left class'),
    '#default_value' => theme_get_setting('dc_sidebar_left_class') ?? 'order-2 order-lg-1',
    '#description' => $help . ' ' . t('Example: %s', ['%s' => 'order-2 order-lg-1']),
  ];
  $form['regions']['dc_sidebar_right_class'] = [
    '#type' => 'textfield',
    '#title' => t('Sidebar right class'),
    '#default_value' => theme_get_setting('dc_sidebar_right_class') ?? 'order-3',
    '#description' => $help . ' ' . t('Example: %s', ['%s' => 'order-3']),
  ];

  $themePath = base_path() . \Drupal::service('extension.list.theme')->getPath('diba_clean');
  $image = '<img src="' . $themePath . '/assets/img/xarxes/{media}.svg" alt="" width="24" height="24">: ';
  $form['social_media'] = [
    '#type' => 'details',
    '#title' => t('Social media links'),
    '#open' => TRUE,
  ];
  $form['social_media']['dc_link_enable'] = [
    '#type' => 'checkbox',
    '#title' => t('Enable social media links'),
    '#default_value' => theme_get_setting('dc_link_enable'),
  ];
  $form['social_media']['dc_link_facebook'] = [
    '#type' => 'url',
    '#title' => str_replace('{media}', 'facebook', $image) . t('Facebook'),
    '#default_value' => theme_get_setting('dc_link_facebook'),
  ];
  $form['social_media']['dc_link_x'] = [
    '#type' => 'url',
    '#title' => str_replace('{media}', 'x', $image) . t('X'),
    '#default_value' => theme_get_setting('dc_link_x'),
  ];
  $form['social_media']['dc_link_instagram'] = [
    '#type' => 'url',
    '#title' => str_replace('{media}', 'instagram', $image) . t('Instagram'),
    '#default_value' => theme_get_setting('dc_link_instagram'),
  ];
  $form['social_media']['dc_link_linkedin'] = [
    '#type' => 'url',
    '#title' => str_replace('{media}', 'linkedin', $image) . t('Linkedin'),
    '#default_value' => theme_get_setting('dc_link_linkedin'),
  ];
  $form['social_media']['dc_link_telegram'] = [
    '#type' => 'url',
    '#title' => str_replace('{media}', 'telegram', $image) . t('Telegram'),
    '#default_value' => theme_get_setting('dc_link_telegram'),
  ];
  $form['social_media']['dc_link_threads'] = [
    '#type' => 'url',
    '#title' => str_replace('{media}', 'threads', $image) . t('Threads'),
    '#default_value' => theme_get_setting('dc_link_threads'),
  ];
  $form['social_media']['dc_link_youtube'] = [
    '#type' => 'url',
    '#title' => str_replace('{media}', 'youtube', $image) . t('Youtube'),
    '#default_value' => theme_get_setting('dc_link_youtube'),
  ];
}
